@@ -16,7 +16,7 @@ object that the YAMLScript code evaluates to.
 # This value is automatically updated by 'make bump'.
 # The version number is used to find the correct shared library file.
 # We currently only support binding to an exact version of libyamlscript.
-yamlscript_version = '0.1.45'
+yamlscript_version = '0.1.56'
 
 import os, sys
 import ctypes
@@ -60,7 +60,11 @@ def find_libyamlscript_path():
 
   if not libyamlscript_path:
     raise Exception(
-      "Shared library file '%s' not found." % libyamlscript_name)
+      """\
+Shared library file '%s' not found
+Try: curl https://yamlscript.org/install | VERSION=%s LIB=1 bash
+See: https://github.com/yaml/yamlscript/wiki/Installing-YAMLScript
+""" % (libyamlscript_name, yamlscript_version))
 
   return libyamlscript_path
 
@@ -92,12 +96,15 @@ class YAMLScript():
     self.isolatethread = ctypes.c_void_p()
 
     # Create a new GraalVM isolate:
-    libyamlscript.graal_create_isolate(
+    rc = libyamlscript.graal_create_isolate(
       None,
       None,
       ctypes.byref(self.isolatethread),
     )
 
+    if rc != 0:
+      raise Exception("Failed to create isolate")
+
   # Compile and eval a YAMLScript string and return the result:
   def load(self, input):
     # Reset any previous error:
@@ -128,6 +135,6 @@ class YAMLScript():
   # YAMLScript instance destructor:
   def __del__(self):
     # Tear down the isolate thread to free resources:
-    ret = libyamlscript.graal_tear_down_isolate(self.isolatethread)
-    if ret != 0:
-      raise Exception("Failed to tear down isolate.")
+    rc = libyamlscript.graal_tear_down_isolate(self.isolatethread)
+    if rc != 0:
+      raise Exception("Failed to tear down isolate")
